pub struct ChartCanvas { /* private fields */ }Implementations
Sourceimpl ChartCanvas
impl ChartCanvas
pub fn new(spec: ChartSpec) -> Result<Self, ModelError>
Creates a ChartCanvas that renders a shared ChartEngine.
This is primarily intended for diagnostics harnesses and multi-surface adapters that need to hold an engine handle outside the widget tree.
pub fn new_grid_view(engine: Rc<RefCell<ChartEngine>>, grid: GridId) -> Self
pub fn new_overlay(engine: Rc<RefCell<ChartEngine>>) -> Self
pub fn set_text_cache_prune_tuning(&mut self, tuning: ChartTextCachePruneTuning)
pub fn engine(&self) -> &ChartEngine
pub fn engine_mut(&mut self) -> &mut ChartEngine
pub fn set_style(&mut self, style: ChartStyle)
pub fn set_style_source(&mut self, source: ChartStyleSource)
pub fn set_tooltip_formatter(&mut self, formatter: Box<dyn TooltipFormatter>)
pub fn set_input_map(&mut self, map: ChartInputMap)
pub fn set_accessibility_layer(&mut self, enabled: bool)
pub fn test_id(self, id: impl Into<String>) -> Self
pub fn linked_brush(self, brush: Model<Option<BrushSelectionLink2D>>) -> Self
pub fn linked_axis_pointer( self, axis_pointer: Model<Option<AxisPointerLinkAnchor>>, ) -> Self
pub fn linked_domain_windows( self, windows: Model<BTreeMap<LinkAxisKey, Option<DataWindow>>>, ) -> Self
pub fn link_axis_map(self, map: BTreeMap<AxisId, LinkAxisKey>) -> Self
pub fn output_model(self, output: Model<ChartCanvasOutput>) -> Self
pub fn create_node<H: UiHost>(ui: &mut UiTree<H>, canvas: Self) -> NodeId