pub struct ChartCanvasOutputSnapshot {
pub brush_selection_2d: Option<BrushSelection2D>,
pub brush_x_row_ranges_by_series: BTreeMap<SeriesId, RowRange>,
pub link_events: Vec<LinkEvent>,
pub tooltip_lines: Vec<TooltipTextLine>,
pub domain_windows_by_key: BTreeMap<LinkAxisKey, Option<DataWindow>>,
}Fields
brush_selection_2d: Option<BrushSelection2D>brush_x_row_ranges_by_series: BTreeMap<SeriesId, RowRange>link_events: Vec<LinkEvent>tooltip_lines: Vec<TooltipTextLine>domain_windows_by_key: BTreeMap<LinkAxisKey, Option<DataWindow>>The current effective domain windows keyed in LinkAxisKey space.
This is used by LinkedChartGroup to propagate domain window changes even when link
events are not observed (for example, when a consumer polls outputs rather than draining
per-step event queues).